# -*- coding: utf-8 -*-

import requests
import urllib

from django.urls import reverse


class RemoteTestMixin:
    # COUNTRY -
    def v1__l10n_country_list(self, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:country-list',
            args=('',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1__l10n_country_retrieve(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:country-detail',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1__l10n_country_create(self, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:country-list',
            args=('',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__l10n_country_update(self, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:country-detail',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__l10n_country_enable(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:country-enable',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__l10n_country_disable(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:country-disable',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__l10n_country_destroy(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:country-detail',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp

    # ADMINISTRATIVE AREA -

    def v1__l10n_administrative_area_list(self, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:administrativearea-list',
            args=('',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1__l10n_administrative_area_retrieve(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:administrativearea-detail',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1__l10n_administrative_area_create(self, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:administrativearea-list',
            args=('',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__l10n_administrative_area_update(self, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:administrativearea-detail',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__l10n_administrative_area_enable(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:administrativearea-enable',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__l10n_administrative_area_disable(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:administrativearea-disable',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1__l10n_administrative_area_destroy(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-l10n:administrativearea-detail',
            args=('', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp
